@@ -254,7 +254,6 @@ class DimShuffle(ExternalCOp):
         return self(*eval_points, return_list=True)
 
     def grad(self, inp, grads):
-
         (x,) = inp
         (gz,) = grads
         gz = as_tensor_variable(gz)
@@ -327,7 +326,7 @@ class Elemwise(OpenMPOp):
     the second input is completed along the first dimension to match the first input
     -``Elemwise(true_divide)(np.random.random(10, 5), np.random.random(10, 1))``: same but along the
     second dimension
-    -``Elemwise(int_div)(np.random.random((1, 5)), np.random.random((10, 1)))``:
+    -``Elemwise(floor_div)(np.random.random((1, 5)), np.random.random((10, 1)))``:
     the output has size ``(10, 5)``.
     -``Elemwise(log)(np.random.random((3, 4, 5)))``
 
@@ -535,7 +534,6 @@ class Elemwise(OpenMPOp):
         return rval
 
     def connection_pattern(self, node):
-
         if hasattr(self.scalar_op, "connection_pattern"):
             return self.scalar_op.connection_pattern(node)
 
@@ -681,7 +679,6 @@ class Elemwise(OpenMPOp):
             and self.ufunc is None
             and impl == "py"
         ):
-
             ufunc = np.frompyfunc(
                 self.scalar_op.impl, len(node.inputs), self.scalar_op.nout
             )
@@ -823,7 +820,6 @@ class Elemwise(OpenMPOp):
                 storage[0] = variable
 
     def infer_shape(self, fgraph, node, i_shapes) -> List[Tuple[TensorVariable, ...]]:
-
         if len(node.outputs) > 1:
             from aesara.tensor.exceptions import ShapeError
 
@@ -1015,7 +1011,7 @@ class Elemwise(OpenMPOp):
                 # No loops
                 task_decl = "".join(
                     [
-                        "{}& {}_i = *{}_iter;\n".format(dtype, name, name)
+                        f"{dtype}& {name}_i = *{name}_iter;\n"
                         for name, dtype in zip(
                             inames + list(real_onames), idtypes + list(real_odtypes)
                         )
@@ -1342,7 +1338,6 @@ class CAReduce(COp):
         return self._ufunc
 
     def _output_dtype(self, idtype):
-
         if not self.upcast_discrete_output:
             return idtype
 
@@ -1525,7 +1520,6 @@ class CAReduce(COp):
         return ([ishape[i] for i in range(node.inputs[0].type.ndim) if i not in axis],)
 
     def _c_all(self, node, name, inames, onames, sub):
-
         input = node.inputs[0]
         output = node.outputs[0]
 
